pub struct Executions { /* private fields */ }Expand description
Implements a client for the Workflow Executions API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = Executions::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_executions()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Executions is used to start and manage running instances of [Workflows][google.cloud.workflows.v1.Workflow] called executions.
Configuration
To configure Executions use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://workflowexecutions.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
Executions holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap Executions in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl Executions
impl Executions
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for Executions.
let client = Executions::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: Executions + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: Executions + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_executions(&self) -> ListExecutions
pub fn list_executions(&self) -> ListExecutions
Returns a list of executions which belong to the workflow with the given name. The method returns executions of all workflow revisions. Returned executions are ordered by their start time (newest first).
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_workflows_executions_v1::Result;
async fn sample(
client: &Executions, parent: &str
) -> Result<()> {
let mut list = client.list_executions()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn create_execution(&self) -> CreateExecution
pub fn create_execution(&self) -> CreateExecution
Creates a new execution using the latest revision of the given workflow.
Example
use google_cloud_workflows_executions_v1::model::Execution;
use google_cloud_workflows_executions_v1::Result;
async fn sample(
client: &Executions, parent: &str
) -> Result<()> {
let response = client.create_execution()
.set_parent(parent)
.set_execution(
Execution::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_execution(&self) -> GetExecution
pub fn get_execution(&self) -> GetExecution
Returns an execution of the given name.
Example
use google_cloud_workflows_executions_v1::Result;
async fn sample(
client: &Executions, name: &str
) -> Result<()> {
let response = client.get_execution()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn cancel_execution(&self) -> CancelExecution
pub fn cancel_execution(&self) -> CancelExecution
Cancels an execution of the given name.
Example
use google_cloud_workflows_executions_v1::Result;
async fn sample(
client: &Executions
) -> Result<()> {
let response = client.cancel_execution()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for Executions
impl Clone for Executions
Sourcefn clone(&self) -> Executions
fn clone(&self) -> Executions
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more