#[non_exhaustive]pub enum CallLogLevel {
Unspecified,
LogAllCalls,
LogErrorsOnly,
LogNone,
UnknownValue(UnknownValue),
}Expand description
Describes the level of platform logging to apply to calls and call responses during workflow executions.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
No call logging level specified.
LogAllCalls
Log all call steps within workflows, all call returns, and all exceptions raised.
LogErrorsOnly
Log only exceptions that are raised from call steps within workflows.
LogNone
Explicitly log nothing.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using CallLogLevel::value or CallLogLevel::name.
Implementations